==> nextcloud-27.1.1p0.tgz: nextcloud/apps/user_status/l10n/hu.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Legutóbbi állapotok",
    "No recent status changes" : "Nincsenek legutóbbi állapotváltozások",
    "In a meeting" : "Találkozón",
    "Commuting" : "Ingázás",
    "Out sick" : "Betegszabadságon",
    "Vacationing" : "Szabadságon",
    "Working remotely" : "Távoli munkavégzés",
    "In a call" : "Hívásban",
    "User status" : "Felhasználói állapot",
    "View profile" : "Profil megtekintése",
    "Clear status after" : "Állapot törlése ennyi idő után",
    "Emoji for your status message" : "Emodzsi az állapotüzenetéhez",
    "What is your status?" : "Mi az állapota?",
    "Predefined statuses" : "Előre meghatározott állapotok",
    "Previously set" : "Előzőleg beállított",
    "Reset status" : "Állapot visszaállítása",
    "Set status" : "Állapot beállítása",
    "Online status" : "Elérhető állapot",
    "Status message" : "Állapotüzenet",
    "Your status was set automatically" : "Az állapota automatikusan lett beállítva",
    "Clear status message" : "Állapotüzenet törlése",
    "Set status message" : "Állapotüzenet beállítása",
    "Reset status to \"{icon} {message}\"" : "Állapot visszaállítása erre: „{icon} {message}”",
    "Reset status to \"{message}\"" : "Állapot visszaállítása erre: „{message}”",
    "Reset status to \"{icon}\"" : "Állapot visszaállítása erre: „{icon}”",
    "There was an error saving the status" : "Hiba történt az állapot mentése során",
    "There was an error clearing the status" : "Hiba történt az állapot törlése sorá",
    "There was an error reverting the status" : "Hiba történt az állapot visszaállítása során",
    "Don't clear" : "Ne törölje",
    "Today" : "Ma",
    "This week" : "Ezen a héten",
    "Online" : "Elérhető",
    "Away" : "Távol",
    "Do not disturb" : "Ne zavarjanak",
    "Invisible" : "Láthatatlan",
    "Offline" : "Nem kapcsolódott",
    "There was an error saving the new status" : "Hiba történt az új állapot mentése sorá",
    "30 minutes" : "30 perc",
    "1 hour" : "1 óra",
    "4 hours" : "4 óra",
    "Mute all notifications" : "Összes értesítés némítása",
    "Appear offline" : "Megjelenés nem kapcsolódottként",
    "{status}, {timestamp}" : "{status}, {timestamp}"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.11p0.tgz: nextcloud/apps/user_status/l10n/hu.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Legutóbbi állapotok",
    "No recent status changes" : "Nincsenek legutóbbi állapotváltozások",
    "In a meeting" : "Találkozón",
    "Commuting" : "Ingázás",
    "Out sick" : "Betegszabadságon",
    "Vacationing" : "Szabadságon",
    "Out of office" : "Irodán kívül",
    "Working remotely" : "Távoli munkavégzés",
    "In a call" : "Hívásban",
    "User status" : "Felhasználói állapot",
    "Clear status after" : "Állapot törlése ennyi idő után",
    "Emoji for your status message" : "Emodzsi az állapotüzenetéhez",
    "What is your status?" : "Mi az állapota?",
    "Predefined statuses" : "Előre meghatározott állapotok",
    "Previously set" : "Előzőleg beállított",
    "Reset status" : "Állapot visszaállítása",
    "Set status" : "Állapot beállítása",
    "Online status" : "Elérhető állapot",
    "Status message" : "Állapotüzenet",
    "Your status was set automatically" : "Az állapota automatikusan lett beállítva",
    "Clear status message" : "Állapotüzenet törlése",
    "Set status message" : "Állapotüzenet beállítása",
    "Reset status to \"{icon} {message}\"" : "Állapot visszaállítása erre: „{icon} {message}”",
    "Reset status to \"{message}\"" : "Állapot visszaállítása erre: „{message}”",
    "Reset status to \"{icon}\"" : "Állapot visszaállítása erre: „{icon}”",
    "There was an error saving the status" : "Hiba történt az állapot mentése során",
    "There was an error clearing the status" : "Hiba történt az állapot törlése sorá",
    "There was an error reverting the status" : "Hiba történt az állapot visszaállítása során",
    "Don't clear" : "Ne törölje",
    "Today" : "Ma",
    "This week" : "Ezen a héten",
    "Online" : "Elérhető",
    "Away" : "Távol",
    "Do not disturb" : "Ne zavarjanak",
    "Invisible" : "Láthatatlan",
    "Offline" : "Nem kapcsolódott",
    "There was an error saving the new status" : "Hiba történt az új állapot mentése sorá",
    "30 minutes" : "30 perc",
    "1 hour" : "1 óra",
    "4 hours" : "4 óra",
    "Mute all notifications" : "Összes értesítés némítása",
    "Appear offline" : "Megjelenés nem kapcsolódottként",
    "View profile" : "Profil megtekintése"
},
"nplurals=2; plural=(n != 1);");
